The ``LoopValueRecorder`` class
###############################

.. autoclass:: pylife.stress.rainflow.LoopValueRecorder
               :members:
               :undoc-members:
               :special-members: __init__
